"""
:type: dict
:Size: 1.752MB

Dictionary file for delemmatizer.
"""
NAME = "TProcess.NLTKWordNetDelemma"
DOWNLOAD = "https://cdn.data.thunlp.org/TAADToolbox/word_delemma.pkl"
# LOAD = pickle
